# polgas.mod	OOR2-MN-n-m
# Original AMPL coding by Sven Leyffer

# A nonconvex gas network problem
#
# MINLP formulation: pipe diameters belong to a discrete set

# Number of variables:              1140
#   of which integer variables:      924
# Number of SOS1 variables:           77
# Number of constraints:             293
#   of which nonlinear constraints:  139
# Objective partially separable nonconvex
# Nonlinear constraints

set NODES := {52, 53, 54,  55,  56,  57,  58,  59,  
        60,  63,  68, 
        75,  76,  77,  
        87,  88,  89,  
        90,  91,  98,  
       104,  105,  106,  
       110,  111,  112,  113,  
       164,  165,  166,  167,  168,  169,  
       170,  171,  172,  174,  175,  176,  177,  179,
       181,  182,  184,  186,  187,  188,  189,
       190,  192,  193,  194,  195,  197,  198,  199, 
       200,  201,  202,  203,  204,  205,  207 } ;


set ROOT  := {53};
set PIPES within (NODES cross NODES);
set nSOS1 := 1..12;                 # 12 possible values for diameters

var v {PIPES} >= 0.1, <= 5.0;       # velocity of flow in arc
var d {PIPES} >= 25;                # diameter of arc
var p {NODES} >= 1500;              # pressure at nodes
var y {PIPES,nSOS1} >= 0, <= 1, binary;

param l {PIPES};                    # length of pipes
param L {NODES};                    # Load at node k
param dv{nSOS1};                    # diamtere values

minimize Cost: 
         118.49 * sum {(i,j) in PIPES} ( l[i,j] * (d[i,j]/1000)^1.3 );

subject to 
	dp {(i,j) in PIPES}:
        (p[i] - p[j]) - 8.587 * l[i,j] * v[i,j]^2 / d[i,j] = 0;

	balance {i in NODES diff ROOT}:
         - sum {(i,j) in PIPES} ( 2.82743E-3 * d[i,j]^2 * v[i,j] ) 
         + sum {(j,i) in PIPES} ( 2.82743E-3 * d[j,i]^2 * v[j,i] ) - L[i] = 0;

	diameter {(i,j) in PIPES}:
     	 d[i,j] = sum{k in nSOS1} ( y[i,j,k] * dv[k] );

	SOS1 {(i,j) in PIPES}: 1 = sum{k in nSOS1} ( y[i,j,k] );


